# file test_xmlmap/__init__.py
# 
#   Copyright 2011 Emory University Libraries
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

from test_xmlmap.test_core import *
from test_xmlmap.test_fields import *
from test_xmlmap.test_ead import *
from test_xmlmap.test_tei import *
from test_xmlmap.test_dc import *
from test_xmlmap.test_cerp import *
from test_xmlmap.test_mods import *
from test_xmlmap.test_premis import *
